==> qtjambi-nfc-6.4.2-sources.jar: io/qt/nfc/QNdefNfcTextRecord.java <==
package io.qt.nfc;


/**
 * <p>NFC RTD-Text</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qndefnfctextrecord.html">QNdefNfcTextRecord</a></p>
 */
public class QNdefNfcTextRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::Encoding</a></p>
     */
    public enum Encoding implements io.qt.QtEnumerator {
        Utf8(0),
        Utf16(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Encoding(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Encoding resolve(int value) {
            switch (value) {
            case 0: return Utf8;
            case 1: return Utf16;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord">QNdefNfcTextRecord::QNdefNfcTextRecord()</a></p>
     */
    public QNdefNfcTextRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord-1">QNdefNfcTextRecord::QNdefNfcTextRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcTextRecord(io.qt.nfc.QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#encoding">QNdefNfcTextRecord::encoding()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.nfc.QNdefNfcTextRecord.Encoding encoding(){
        return io.qt.nfc.QNdefNfcTextRecord.Encoding.resolve(encoding_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int encoding_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#locale">QNdefNfcTextRecord::locale()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String locale(){
        return locale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String locale_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setEncoding">QNdefNfcTextRecord::setEncoding(QNdefNfcTextRecord::Encoding)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setEncoding(io.qt.nfc.QNdefNfcTextRecord.Encoding encoding){
        setEncoding_native_QNdefNfcTextRecord_Encoding(QtJambi_LibraryUtilities.internal.nativeId(this), encoding.value());
    }
    
    @io.qt.QtUninvokable
    private native void setEncoding_native_QNdefNfcTextRecord_Encoding(long __this__nativeId, int encoding);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setLocale">QNdefNfcTextRecord::setLocale(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setLocale(java.lang.String locale){
        setLocale_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), locale);
    }
    
    @io.qt.QtUninvokable
    private native void setLocale_native_cref_QString(long __this__nativeId, java.lang.String locale);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setText">QNdefNfcTextRecord::setText(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setText(java.lang.String text){
        setText_native_const_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @io.qt.QtUninvokable
    private native void setText_native_const_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#text">QNdefNfcTextRecord::text()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNdefNfcTextRecord(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QNdefNfcTextRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNdefNfcTextRecord clone_native(long __this_nativeId);
}

==> qtjambi-nfc-6.5.1-sources.jar: io/qt/nfc/QNdefNfcTextRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>NFC RTD-Text</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qndefnfctextrecord.html">QNdefNfcTextRecord</a></p>
 */
public class QNdefNfcTextRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::Encoding</a></p>
     */
    public enum Encoding implements QtEnumerator {
        /**
         * <p>Representing <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::Utf8</a></p>
         */
        Utf8(0),
        /**
         * <p>Representing <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::Utf16</a></p>
         */
        Utf16(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Encoding(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Encoding resolve(int value) {
            switch (value) {
            case 0: return Utf8;
            case 1: return Utf16;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord">QNdefNfcTextRecord::QNdefNfcTextRecord()</a></p>
     */
    public QNdefNfcTextRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord-1">QNdefNfcTextRecord::QNdefNfcTextRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcTextRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#encoding">QNdefNfcTextRecord::encoding()const</a></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNdefNfcTextRecord.@NonNull Encoding encoding(){
        return io.qt.nfc.QNdefNfcTextRecord.Encoding.resolve(encoding_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int encoding_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#locale">QNdefNfcTextRecord::locale()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String locale(){
        return locale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String locale_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setEncoding">QNdefNfcTextRecord::setEncoding(QNdefNfcTextRecord::Encoding)</a></p>
     */
    @QtUninvokable
    public final void setEncoding(io.qt.nfc.QNdefNfcTextRecord.@NonNull Encoding encoding){
        setEncoding_native_QNdefNfcTextRecord_Encoding(QtJambi_LibraryUtilities.internal.nativeId(this), encoding.value());
    }
    
    @QtUninvokable
    private native void setEncoding_native_QNdefNfcTextRecord_Encoding(long __this__nativeId, int encoding);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setLocale">QNdefNfcTextRecord::setLocale(QString)</a></p>
     */
    @QtUninvokable
    public final void setLocale(java.lang.@NonNull String locale){
        setLocale_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), locale);
    }
    
    @QtUninvokable
    private native void setLocale_native_cref_QString(long __this__nativeId, java.lang.String locale);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setText">QNdefNfcTextRecord::setText(QString)</a></p>
     */
    @QtUninvokable
    public final void setText(java.lang.@NonNull String text){
        setText_native_const_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @QtUninvokable
    private native void setText_native_const_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfctextrecord.html#text">QNdefNfcTextRecord::text()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNdefNfcTextRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcTextRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcTextRecord clone_native(long __this_nativeId);
}
